@@ -3,31 +3,69 @@
 # Author      : E.Taskesen
 # Contact     : erdogant@gmail.com
 # github      : https://github.com/erdogant/distfit
-# Licence     : MIT
 # --------------------------------------------------
 
 import numpy as np
-import distfit as distfit
+import distfit
 # print(distfit.__version__)
+# print(dir(distfit))
+
+# %%
+from distfit import distfit
+X = np.random.normal(0, 2, 5000)
+y = [-8,-6,0,1,2,3,4,5,6]
+# dist = distfit(stats='RSS')
+# dist = distfit(stats='wasserstein')
+dist = distfit(stats='energy')
+# dist = distfit(stats='ks')
+dist.fit_transform(X)
+dist.plot_summary()
+# dist.plot()
+
+
+# %%
+from distfit import distfit
+from scipy.stats import binom
+# Generate random numbers
+X = binom(8, 0.5).rvs(1000)
+
+dist = distfit(method='discrete', f=1.5, weighted=True)
+model = dist.fit_transform(X, verbose=3)
+dist.plot()
+
+# Make prediction
+results = dist.predict([0, 1, 10, 11, 12])
+dist.plot()
 
 
 # %% Import class
 from distfit import distfit
-# print(dir(distfit))
 
 # %%
 # from sklearn.datasets.samples_generator import make_blobs
 # [data, labels_true] = make_blobs(n_samples=10000, centers=3, n_features=1, cluster_std=0.3, random_state=0)
 
+# %%
+from distfit import distfit
+X = np.random.normal(0, 2, 5000)
+y = [-8,-6,0,1,2,3,4,5,6]
+dist = distfit(distr='loggamma')
+dist.fit_transform(X)
+dist.plot()
 
 # %%
+from distfit import distfit
 X = np.random.normal(0, 2, 5000)
 y = [-8,-6,0,1,2,3,4,5,6]
 
-dist = distfit()
+dist = distfit(distr='popular', todf=False)
 model = dist.fit_transform(X)
 dist.plot()
 
+dist = distfit(distr='popular', todf=True)
+dist.fit_transform(X)
+dist.plot()
+
 # Make prediction
 results = dist.predict(y)
 
@@ -36,7 +74,7 @@ dist.plot()
 dist.plot_summary()
 
 # Save
-dist.save(filepath='c:\\temp\\model.pkl')
+dist.save(filepath='c:\\temp\\model.pkl', overwrite=True)
 # Load
 dist.load(filepath='c:\\temp\\model.pkl')
 
@@ -51,30 +89,35 @@ model.plot()
 
 # %%
 # Create random data with varying number of samples
-import pandas as pd
-samples = np.arange(250, 20000, 250)
 
 #%%
 # Initialize model
-smooth_window=[None,1,3,5,7,9,11]
+import matplotlib.pyplot as plt
+from tqdm import tqdm
+import pandas as pd
+samples = np.arange(250, 20000, 250)
+smooth_window=[None,2,4,6,8,10]
 plt.figure(figsize=(15,10))
 
-for smooth in smooth_window:
+for smooth in tqdm(smooth_window):
     dist = distfit(distr='norm', smooth=smooth)
     # Estimate paramters for the number of samples
     out = []
     for s in samples:
         X = np.random.normal(0, 2, s)
         dist.fit_transform(X, verbose=0)
-        out.append([dist.model['loc'], dist.model['scale'], dist.model['name'], np.where(dist.summary['distr']=='norm')[0][0], s])
+        # out.append([dist.model['RSS'], dist.model['name'], np.where(dist.summary['distr']=='norm')[0][0], s])
+        out.append([dist.model['scale'], dist.model['name'], s])
 
-    df=pd.DataFrame(out, columns=['std','mu','name','norm_place','samples'])
+    df=pd.DataFrame(out, columns=['mu','name','samples'])
     ax=df['mu'].plot(grid=True, label='smooth: '+str(smooth) + ' - ' + str(df['mu'].mean()))
 
 ax.set_xlabel('Nr.Samples')
 ax.set_ylabel('mu')
 ax.set_xticks(np.arange(0,len(samples)))
-ax.set_xticklabels(samples.astype(str))
+ax.set_xticklabels(samples.astype(str), rotation = 90)
+# ax.set_ylim([0, 0.02])
+# ax.set_ylim([1.9, 2.1])
 ax.legend()
 
 # ax=df['std'].plot(grid=True)
@@ -83,11 +126,42 @@ ax.legend()
 # ax.set_xticks(np.arange(0,len(samples)))
 # ax.set_xticklabels(samples.astype(str))
 
+#%%
+# Initialize model
+import matplotlib.pyplot as plt
+from tqdm import tqdm
+import pandas as pd
+samples = np.arange(250, 20000, 250)
+smooth_window=[None, 2,4,6,8,10]
+plt.figure(figsize=(15,10))
+
+for smooth in tqdm(smooth_window):
+    dist = distfit(distr='uniform', smooth=smooth)
+    # dist = distfit(smooth=smooth)
+    # Estimate paramters for the number of samples
+    out = []
+    for s in samples:
+        X = np.random.randint(0, 100, s)
+        dist.fit_transform(X, verbose=0)
+        # out.append([dist.model['RSS'], dist.model['name'], np.where(dist.summary['distr']=='uniform')[0][0], s])
+        out.append([dist.model['RSS'], dist.model['name'], s])
+
+    df = pd.DataFrame(out, columns=['RSS','name','samples'])
+    ax=df['RSS'].plot(grid=True, label='smooth: '+str(smooth) + ' - RSS: ' + str(df['RSS'].mean()))
+
+ax.set_xlabel('Nr.Samples')
+ax.set_ylabel('RSS')
+ax.set_xticks(np.arange(0,len(samples)))
+ax.set_xticklabels(samples.astype(str), rotation = 90)
+ax.set_ylim([0, 0.0005])
+ax.legend()
+
+
 # %% Fit and transform
 X = np.random.beta(5, 8, [100,100])
 y = [-1,-0.8,-0.6,0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1,1.1,1.5]
 
-dist = distfit()
+dist = distfit(stats='wasserstein')
 dist.fit()
 dist.transform(X)
 dist.plot()
@@ -109,9 +183,9 @@ model.plot()
 model.plot_summary()
 
 # %% Show some results
-print(model.y_proba)
-print(model.y_pred)
-print(model.df)
+print(model.results['y_proba'])
+print(model.results['y_pred'])
+# print(model.results['df'])
 print(model.summary)
 
 
@@ -119,7 +193,7 @@ print(model.summary)
 X = np.random.normal(0, 2, 1000)
 y = [-8,-6,0,1,2,3,4,5,6]
 
-model = dist(method='emperical')
+model = distfit()
 model.fit_transform(X)
 model.plot()
 
@@ -135,15 +209,17 @@ model = distfit()
 model.fit_transform(X)
 model.predict(y)
 model.plot()
+model.results['y_proba']
+model.results['y_pred']
 
-model = dist(method='emperical')
+model = distfit(todf=True)
 model.fit_transform(X)
 model.predict(y)
 model.plot()
 
-model.y_proba
-model.y_pred
-model.df
+model.results['y_proba']
+model.results['y_pred']
+model.results['df'] # Only availble when using todf=True
 
 # %%
 X = np.random.beta(5, 8, 1000)
@@ -172,23 +248,27 @@ model.plot()
 X = np.random.normal(0, 2, 1000)
 y = [-8,-6,0,1,2,3,4,5,6]
 
-model = distfit()
+model = distfit(todf=True)
 model.fit_transform(X)
 model.predict(y)
 model.plot()
-model.df
 
-model = dist(bound='up')
-model.fit_transform(X)
-model.predict(y)
-model.plot()
-model.df
+model.results['y_proba']
+model.results['y_pred']
+model.results['df']
 
-model = dist(bound='down')
+
+model = distfit(bound='up', todf=True)
 model.fit_transform(X)
 model.predict(y)
 model.plot()
-model.df
+model.results['df']
+
+model = distfit(bound='down', todf=True)
+model.fit_transform(X)
+model.predict(y)
+model.plot()
+model.results['df']
 
 # %% Find best fit distribution
 X = np.random.normal(0, 2, 1000)
@@ -198,24 +278,34 @@ model = distfit()
 model.fit_transform(X)
 model.plot()
 
-model = dist(distr='popular')
+model = distfit(distr='popular')
 model.fit_transform(X)
 model.plot()
 
-model = dist(distr='full')
+model = distfit(distr='full')
 model.fit_transform(X)
 model.plot()
 
 
-# %%
+# %% Quantile approach
+from distfit import distfit
+import numpy as np
+
 X = np.random.normal(10, 3, 2000)
 y = [3,4,5,6,10,11,12,18,20]
 
 # Initialize
-dist = distfit(distr='full', alpha=0.05)
+dist = distfit(method='percentile', alpha=0.05, todf=False)
+# dist = distfit(method='quantile', alpha=0.05, todf=False)
 dist.fit_transform(X)
 dist.plot()
 
 # Make prediction
 dist.predict(y)
 dist.plot()
+dist.plot_summary()
+
+# from tabulate import tabulate
+# print(tabulate(dist.results['df'], tablefmt="grid", headers="keys"))
+
+# %%
